# - caliper: Context Annotation Library
#
#=============================================================================
# Caliper is a program instrumentation and performance measurement
# framework. It provides data collection mechanisms and a source-code
# annotation API for a variety of performance engineering use cases,
# e.g., performance profiling, tracing, monitoring, and
# auto-tuning.
#
#=== Usage ===================================================================
# This file allows caliper to be automatically detected by other libraries
# using CMake.  To build with caliper, you can do one of two things:
#
#   1. Set the caliper_DIR environment variable to the root of the Caliper
#      installation.  If you loaded caliper through a dotkit, this may already
#      be set, and caliper will be autodetected by CMake.
#
#   2. Configure your project with this option:
#      -Dcaliper_DIR=<caliper install prefix>/share/
#
# If you have done either of these things, then CMake should automatically find
# and include this file when you call find_package(caliper) from your
# CMakeLists.txt file.
#
#=== Components ==============================================================
# (David's TO DO)
#
# To link against these, just do, for example:
#
#   find_package(caliper REQUIRED)
#   add_executable(foo foo.c)
#   target_link_libraries(foo caliper)
#
# That's all!
#
if (NOT caliper_CONFIG_LOADED)
  set(caliper_CONFIG_LOADED TRUE)

  # Install layout
  set(caliper_INSTALL_PREFIX /usr)
  set(caliper_INCLUDE_DIR    /usr/include)
  set(caliper_LIB_DIR        /usr/lib64)
  set(caliper_CMAKE_DIR      /usr/share/cmake/caliper)

  # Includes needed to use caliper
  set(caliper_INCLUDE_PATH ${caliper_INCLUDE_DIR})
  set(caliper_LIB_PATH     ${caliper_LIB_DIR})

  include(CMakeFindDependencyMacro)
  find_dependency(Threads)

  if ()
    find_dependency(adiak)
  endif()

  # Library targets imported from file
  include(${caliper_CMAKE_DIR}/caliper-targets.cmake)
endif()
